@@ -3,3 +3,5 @@ RESERVED_KWARGS = {"state", "headers", "cookies", "request", "socket", "data", "
 EXTRA_KEY_REQUIRED = "required"
 EXTRA_KEY_VALUE_TYPE = "value_type"
 EXTRA_KEY_IS_PARAMETER = "is_parameter"
+EXTRA_KEY_IS_DEPENDENCY = "is_dependency"
+EXTRA_KEY_SKIP_VALIDATION = "skip_validation"
