@@ -29,44 +29,44 @@ class OpenAPIController(Controller):
 
     @staticmethod
     def schema_from_request(request: Request) -> "OpenAPI":
-        """Returns the openapi schema"""
+        """Returns the openapi schema."""
         if not request.app.openapi_schema:  # pragma: no cover
             raise ImproperlyConfiguredException("Starlite has not been instantiated with OpenAPIConfig")
         return request.app.openapi_schema
 
     @get(path="/", media_type=MediaType.HTML, include_in_schema=False)
     def root(self, request: Request) -> str:
-        """
-        This route handler serves Redoc API documentation at the root path.
-        Override this handler to serve custom templates or other API documentation, such as
-        `render_swagger_ui`, `render_stoplight_elements`, a template, or your own content.
+        """This route handler serves Redoc API documentation at the root path.
+
+        Override this handler to serve custom templates or other API
+        documentation, such as `render_swagger_ui`,
+        `render_stoplight_elements`, a template, or your own content.
         """
         return self.render_redoc(request)
 
     @get(path="/openapi.yaml", media_type=OpenAPIMediaType.OPENAPI_YAML, include_in_schema=False)
     def retrieve_schema_yaml(self, request: Request) -> "OpenAPI":
-        """Returns the openapi schema"""
+        """Returns the openapi schema."""
         return self.schema_from_request(request)
 
     @get(path="/openapi.json", media_type=OpenAPIMediaType.OPENAPI_JSON, include_in_schema=False)
     def retrieve_schema_json(self, request: Request) -> "OpenAPI":
-        """Returns the openapi schema"""
+        """Returns the openapi schema."""
         return self.schema_from_request(request)
 
     @property
     def favicon(self) -> str:
-        """
-        Returns a link tag if self.favicon_url is not empty, otherwise returns a placeholder meta tag.
-        """
+        """Returns a link tag if self.favicon_url is not empty, otherwise
+        returns a placeholder meta tag."""
         return f"<link rel='icon' type='image/x-icon' href='{self.favicon_url}'>" if self.favicon_url else "<meta/>"
 
     @get(path="/swagger", media_type=MediaType.HTML, include_in_schema=False)
     def swagger_ui(self, request: Request) -> str:
-        """Endpoint that serves SwaggerUI"""
+        """Endpoint that serves SwaggerUI."""
         return self.render_swagger_ui(request)
 
     def render_swagger_ui(self, request: Request) -> str:
-        """Method that renders SwaggerUI from schema"""
+        """Method that renders SwaggerUI from schema."""
         schema = self.schema_from_request(request)
         # Note: Fix for Swagger rejection OpenAPI >=3.1
         # We force the version to be lower to get the default JS bundle to accept it
@@ -120,11 +120,11 @@ class OpenAPIController(Controller):
 
     @get(path="/elements/", media_type=MediaType.HTML, include_in_schema=False)
     def stoplight_elements(self, request: Request) -> str:
-        """Endpoint that serves Stoplight Elements OpenAPI UI"""
+        """Endpoint that serves Stoplight Elements OpenAPI UI."""
         return self.render_stoplight_elements(request)
 
     def render_stoplight_elements(self, request: Request) -> str:
-        """Method that renders Stoplight Elements OpenAPI UI from schema"""
+        """Method that renders Stoplight Elements OpenAPI UI from schema."""
         schema = self.schema_from_request(request)
         head = f"""
           <head>
@@ -156,11 +156,11 @@ class OpenAPIController(Controller):
 
     @get(path="/redoc", media_type=MediaType.HTML, include_in_schema=False)
     def redoc(self, request: Request) -> str:  # pragma: no cover
-        """Endpoint that serves Redoc"""
+        """Endpoint that serves Redoc."""
         return self.render_redoc(request)
 
     def render_redoc(self, request: Request) -> str:  # pragma: no cover
-        """Method that renders Redoc from schema"""
+        """Method that renders Redoc from schema."""
         schema = self.schema_from_request(request)
         if self._dumped_schema == "":
             self._dumped_schema = dumps(schema.json(by_alias=True, exclude_none=True), option=OPT_INDENT_2).decode(
