@@ -17,9 +17,7 @@ if TYPE_CHECKING:
 def create_request_body(
     field: "ModelField", generate_examples: bool, plugins: List["PluginProtocol"]
 ) -> Optional[RequestBody]:
-    """
-    Create a RequestBody model for the given RouteHandler or return None
-    """
+    """Create a RequestBody model for the given RouteHandler or return None."""
     media_type = field.field_info.extra.get("media_type", RequestEncodingType.JSON)
     schema = create_schema(field=field, generate_examples=generate_examples, plugins=plugins)
     update_schema_with_field_info(schema=schema, field_info=field.field_info)
