@@ -12,8 +12,6 @@ from typing import (
 
 from pydantic import validate_arguments
 from pydantic.fields import FieldInfo
-from starlette.middleware import Middleware
-from starlette.middleware.base import BaseHTTPMiddleware
 
 from starlite.controller import Controller
 from starlite.datastructures import Cookie, ResponseHeader
@@ -34,7 +32,7 @@ from starlite.types import (
     ControllerRouterHandler,
     ExceptionHandler,
     Guard,
-    MiddlewareProtocol,
+    Middleware,
 )
 from starlite.utils import (
     find_index,
@@ -78,7 +76,7 @@ class Router:
         dependencies: Optional[Dict[str, Provide]] = None,
         exception_handlers: Optional[Dict[Union[int, Type[Exception]], ExceptionHandler]] = None,
         guards: Optional[List[Guard]] = None,
-        middleware: Optional[List[Union[Middleware, Type[BaseHTTPMiddleware], Type[MiddlewareProtocol]]]] = None,
+        middleware: Optional[List[Middleware]] = None,
         parameters: Optional[Dict[str, FieldInfo]] = None,
         path: str,
         response_class: Optional[Type[Response]] = None,
@@ -87,8 +85,7 @@ class Router:
         route_handlers: List[ControllerRouterHandler],
         tags: Optional[List[str]] = None,
     ):
-        """
-        The Starlite Router class.
+        """The Starlite Router class.
 
         A Router instance is used to group controller, routers and route handler functions under a shared path fragment.
 
@@ -139,11 +136,12 @@ class Router:
             self.register(value=route_handler)
 
     def register(self, value: ControllerRouterHandler) -> List["BaseRoute"]:
-        """
-        Register a Controller, Route instance or RouteHandler on the router
+        """Register a Controller, Route instance or RouteHandler on the router.
 
-        Accepts a subclass or instance of Controller, an instance of Router or a function/method that has been decorated
-        by any of the routing decorators (e.g. route, get, post...) exported from 'starlite.routing'
+        Accepts a subclass or instance of Controller, an instance of
+        Router or a function/method that has been decorated by any of
+        the routing decorators (e.g. route, get, post...) exported from
+        'starlite.routing'
         """
         validated_value = self._validate_registration_value(value)
         routes: List["BaseRoute"] = []
@@ -201,9 +199,7 @@ class Router:
     def _map_route_handlers(
         value: Union[Controller, BaseRouteHandler, "Router"],
     ) -> ItemsView[str, Union[WebsocketRouteHandler, ASGIRoute, Dict["HttpMethod", HTTPRouteHandler]]]:
-        """
-        Maps route handlers to http methods
-        """
+        """Maps route handlers to http methods."""
         handlers_map: Dict[str, Any] = {}
         if isinstance(value, BaseRouteHandler):
             for path in value.paths:
@@ -230,9 +226,8 @@ class Router:
     def _validate_registration_value(
         self, value: ControllerRouterHandler
     ) -> Union[Controller, BaseRouteHandler, "Router"]:
-        """
-        Validates that the value passed to the register method is supported
-        """
+        """Validates that the value passed to the register method is
+        supported."""
         if is_class_and_subclass(value, Controller):
             return cast("Type[Controller]", value)(owner=self)
         if not isinstance(value, (Router, BaseRouteHandler)):
