@@ -4,7 +4,10 @@ T = TypeVar("T")
 
 
 def find_index(target_list: List[T], predicate: Callable[[T], bool]) -> int:
-    """Find element in list given a key and value. List elements can be dicts or classes"""
+    """Find element in list given a key and value.
+
+    List elements can be dicts or classes
+    """
     for i, element in enumerate(target_list):
         if predicate(element):
             return i
@@ -12,7 +15,7 @@ def find_index(target_list: List[T], predicate: Callable[[T], bool]) -> int:
 
 
 def unique(value: Iterable[T]) -> List[T]:
-    """Return all unique values in a given sequence or iterator"""
+    """Return all unique values in a given sequence or iterator."""
     try:
         return list(set(value))
     except TypeError:
